@@ -1,4 +1,5 @@
-from Excelutilities.importing_data_helpers import add_col_data_from_another_sheet
+from Excelutilities import importing_data_helpers 
+add_col_data_from_another_sheet = importing_data_helpers.add_col_data_from_another_sheet
 import decimal
 import datetime
 def import_data():
